@@ -1,14 +1,16 @@
-from urllib import parse
+from __future__ import annotations
+
 from datetime import datetime
-from typing import Any, Dict, Generator, List, Optional, Union
+from typing import Any, Generator
+from urllib import parse
 
 from meilisearch._httprequests import HttpRequests
 from meilisearch.config import Config
+from meilisearch.models.document import Document, DocumentsResults
+from meilisearch.models.index import IndexStats
+from meilisearch.models.task import Task, TaskInfo, TaskResults
 from meilisearch.task import get_task, get_tasks, wait_for_task
 
-from meilisearch.models.index import IndexStats
-from meilisearch.models.document import Document, DocumentsResults
-from meilisearch.models.task import Task, TaskInfo, TaskResults
 
 # pylint: disable=too-many-public-methods
 class Index():
@@ -23,9 +25,9 @@ class Index():
         self,
         config: Config,
         uid: str,
-        primary_key: Optional[str] = None,
-        created_at: Optional[Union[datetime, str]] = None,
-        updated_at: Optional[Union[datetime, str]] = None,
+        primary_key: str | None = None,
+        created_at: datetime | str | None = None,
+        updated_at: datetime | str | None = None,
     ) -> None:
         """
         Parameters
@@ -44,7 +46,7 @@ class Index():
         self.created_at = self._iso_to_date_time(created_at)
         self.updated_at = self._iso_to_date_time(updated_at)
 
-    def delete(self) -> Dict[str, Any]:
+    def delete(self) -> dict[str, Any]:
         """Delete the index.
 
         Raises
@@ -55,7 +57,7 @@ class Index():
 
         return self.http.delete(f'{self.config.paths.index}/{self.uid}')
 
-    def update(self, primary_key: str) -> Dict[str, Any]:
+    def update(self, primary_key: str) -> dict[str, Any]:
         """Update the index primary-key.
 
         Parameters
@@ -77,7 +79,7 @@ class Index():
         payload = {'primaryKey': primary_key}
         return self.http.patch(f'{self.config.paths.index}/{self.uid}', payload)
 
-    def fetch_info(self) -> 'Index':
+    def fetch_info(self) -> Index:
         """Fetch the info of the index.
 
         Raises
@@ -91,7 +93,7 @@ class Index():
         self.updated_at = self._iso_to_date_time(index_dict['updatedAt'])
         return self
 
-    def get_primary_key(self) -> Optional[str]:
+    def get_primary_key(self) -> str | None:
         """Get the primary key.
 
         Raises
@@ -102,7 +104,7 @@ class Index():
         return self.fetch_info().primary_key
 
     @staticmethod
-    def create(config: Config, uid: str, options: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
+    def create(config: Config, uid: str, options: dict[str, Any] | None = None) -> dict[str, Any]:
         """Create the index.
 
         Parameters
@@ -128,7 +130,7 @@ class Index():
         payload = {**options, 'uid': uid}
         return HttpRequests(config).post(config.paths.index, payload)
 
-    def get_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> TaskResults:
+    def get_tasks(self, parameters: dict[str, Any] | None = None) -> TaskResults:
         """Get all tasks of a specific index from the last one.
 
         Parameters
@@ -230,7 +232,7 @@ class Index():
         )
         return IndexStats(stats)
 
-    def search(self, query: str, opt_params: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
+    def search(self, query: str, opt_params: dict[str, Any] | None = None) -> dict[str, Any]:
         """Search in the index.
 
         Parameters
@@ -262,7 +264,7 @@ class Index():
             body=body
         )
 
-    def get_document(self, document_id: str, parameters: Optional[Dict[str, Any]] = None) -> Document:
+    def get_document(self, document_id: str, parameters: dict[str, Any] | None = None) -> Document:
         """Get one document with given document identifier.
 
         Parameters
@@ -292,7 +294,7 @@ class Index():
         )
         return Document(document)
 
-    def get_documents(self, parameters: Optional[Dict[str, Any]] = None) -> DocumentsResults:
+    def get_documents(self, parameters: dict[str, Any] | None = None) -> DocumentsResults:
         """Get a set of documents from the index.
 
         Parameters
@@ -326,8 +328,8 @@ class Index():
 
     def add_documents(
         self,
-        documents: List[Dict[str, Any]],
-        primary_key: Optional[str] = None,
+        documents: list[dict[str, Any]],
+        primary_key: str | None = None,
     ) -> TaskInfo:
         """Add documents to the index.
 
@@ -355,10 +357,10 @@ class Index():
 
     def add_documents_in_batches(
         self,
-        documents: List[Dict[str, Any]],
+        documents: list[dict[str, Any]],
         batch_size: int = 1000,
-        primary_key: Optional[str] = None,
-    ) -> List[TaskInfo]:
+        primary_key: str | None = None,
+    ) -> list[TaskInfo]:
         """Add documents to the index in batches.
 
         Parameters
@@ -383,7 +385,7 @@ class Index():
             Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
 
-        tasks: List[TaskInfo] = []
+        tasks: list[TaskInfo] = []
 
         for document_batch in self._batch(documents, batch_size):
             task = self.add_documents(document_batch, primary_key)
@@ -394,7 +396,7 @@ class Index():
     def add_documents_json(
         self,
         str_documents: str,
-        primary_key: Optional[str] = None,
+        primary_key: str | None = None,
     ) -> TaskInfo:
         """Add string documents from JSON file to the index.
 
@@ -421,7 +423,7 @@ class Index():
     def add_documents_csv(
         self,
         str_documents: str,
-        primary_key: Optional[str] = None,
+        primary_key: str | None = None,
     ) -> TaskInfo:
         """Add string documents from a CSV file to the index.
 
@@ -448,7 +450,7 @@ class Index():
     def add_documents_ndjson(
         self,
         str_documents: str,
-        primary_key: Optional[str] = None,
+        primary_key: str | None = None,
     ) -> TaskInfo:
         """Add string documents from a NDJSON file to the index.
 
@@ -475,8 +477,8 @@ class Index():
     def add_documents_raw(
         self,
         str_documents: str,
-        primary_key: Optional[str] = None,
-        content_type: Optional[str] = None,
+        primary_key: str | None = None,
+        content_type: str | None = None,
     ) -> TaskInfo:
         """Add string documents to the index.
 
@@ -506,8 +508,8 @@ class Index():
 
     def update_documents(
         self,
-        documents: List[Dict[str, Any]],
-        primary_key: Optional[str] = None
+        documents: list[dict[str, Any]],
+        primary_key: str | None = None
     ) -> TaskInfo:
         """Update documents in the index.
 
@@ -535,10 +537,10 @@ class Index():
 
     def update_documents_in_batches(
         self,
-        documents: List[Dict[str, Any]],
+        documents: list[dict[str, Any]],
         batch_size: int = 1000,
-        primary_key: Optional[str] = None
-    ) -> List[TaskInfo]:
+        primary_key: str | None = None
+    ) -> list[TaskInfo]:
         """Update documents to the index in batches.
 
         Parameters
@@ -595,7 +597,7 @@ class Index():
         )
         return TaskInfo(**response)
 
-    def delete_documents(self, ids: List[str]) -> TaskInfo:
+    def delete_documents(self, ids: list[str]) -> TaskInfo:
         """Delete multiple documents from the index.
 
         Parameters
@@ -641,7 +643,7 @@ class Index():
 
     # GENERAL SETTINGS ROUTES
 
-    def get_settings(self) -> Dict[str, Any]:
+    def get_settings(self) -> dict[str, Any]:
         """Get settings of the index.
 
         https://docs.meilisearch.com/reference/api/settings.html
@@ -660,7 +662,7 @@ class Index():
             f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}'
         )
 
-    def update_settings(self, body: Dict[str, Any]) -> Dict[str, Any]:
+    def update_settings(self, body: dict[str, Any]) -> dict[str, Any]:
         """Update settings of the index.
 
         https://docs.meilisearch.com/reference/api/settings.html#update-settings
@@ -688,7 +690,7 @@ class Index():
             body
         )
 
-    def reset_settings(self) -> Dict[str, Any]:
+    def reset_settings(self) -> dict[str, Any]:
         """Reset settings of the index to default values.
 
         https://docs.meilisearch.com/reference/api/settings.html#reset-settings
@@ -710,7 +712,7 @@ class Index():
 
     # RANKING RULES SUB-ROUTES
 
-    def get_ranking_rules(self) -> List[str]:
+    def get_ranking_rules(self) -> list[str]:
         """Get ranking rules of the index.
 
         Returns
@@ -727,7 +729,7 @@ class Index():
             self.__settings_url_for(self.config.paths.ranking_rules)
         )
 
-    def update_ranking_rules(self, body: List[str]) -> Dict[str, Any]:
+    def update_ranking_rules(self, body: list[str]) -> dict[str, Any]:
         """Update ranking rules of the index.
 
         Parameters
@@ -751,7 +753,7 @@ class Index():
             body
         )
 
-    def reset_ranking_rules(self) -> Dict[str, Any]:
+    def reset_ranking_rules(self) -> dict[str, Any]:
         """Reset ranking rules of the index to default values.
 
         Returns
@@ -771,7 +773,7 @@ class Index():
 
     # DISTINCT ATTRIBUTE SUB-ROUTES
 
-    def get_distinct_attribute(self) -> Optional[str]:
+    def get_distinct_attribute(self) -> str | None:
         """Get distinct attribute of the index.
 
         Returns
@@ -788,7 +790,7 @@ class Index():
             self.__settings_url_for(self.config.paths.distinct_attribute)
         )
 
-    def update_distinct_attribute(self, body: Dict[str, Any]) -> Dict[str, Any]:
+    def update_distinct_attribute(self, body: dict[str, Any]) -> dict[str, Any]:
         """Update distinct attribute of the index.
 
         Parameters
@@ -812,7 +814,7 @@ class Index():
             body
         )
 
-    def reset_distinct_attribute(self) -> Dict[str, Any]:
+    def reset_distinct_attribute(self) -> dict[str, Any]:
         """Reset distinct attribute of the index to default values.
 
         Returns
@@ -832,7 +834,7 @@ class Index():
 
     # SEARCHABLE ATTRIBUTES SUB-ROUTES
 
-    def get_searchable_attributes(self) -> List[str]:
+    def get_searchable_attributes(self) -> list[str]:
         """Get searchable attributes of the index.
 
         Returns
@@ -849,7 +851,7 @@ class Index():
             self.__settings_url_for(self.config.paths.searchable_attributes)
         )
 
-    def update_searchable_attributes(self, body: List[str]) -> Dict[str, Any]:
+    def update_searchable_attributes(self, body: list[str]) -> dict[str, Any]:
         """Update searchable attributes of the index.
 
         Parameters
@@ -873,7 +875,7 @@ class Index():
             body
         )
 
-    def reset_searchable_attributes(self) -> Dict[str, Any]:
+    def reset_searchable_attributes(self) -> dict[str, Any]:
         """Reset searchable attributes of the index to default values.
 
         Returns
@@ -893,7 +895,7 @@ class Index():
 
     # DISPLAYED ATTRIBUTES SUB-ROUTES
 
-    def get_displayed_attributes(self) -> List[str]:
+    def get_displayed_attributes(self) -> list[str]:
         """Get displayed attributes of the index.
 
         Returns
@@ -910,7 +912,7 @@ class Index():
             self.__settings_url_for(self.config.paths.displayed_attributes)
         )
 
-    def update_displayed_attributes(self, body: List[str]) -> Dict[str, Any]:
+    def update_displayed_attributes(self, body: list[str]) -> dict[str, Any]:
         """Update displayed attributes of the index.
 
         Parameters
@@ -934,7 +936,7 @@ class Index():
             body
         )
 
-    def reset_displayed_attributes(self) -> Dict[str, Any]:
+    def reset_displayed_attributes(self) -> dict[str, Any]:
         """Reset displayed attributes of the index to default values.
 
         Returns
@@ -954,7 +956,7 @@ class Index():
 
     # STOP WORDS SUB-ROUTES
 
-    def get_stop_words(self) -> List[str]:
+    def get_stop_words(self) -> list[str]:
         """Get stop words of the index.
 
         Returns
@@ -971,7 +973,7 @@ class Index():
             self.__settings_url_for(self.config.paths.stop_words)
         )
 
-    def update_stop_words(self, body: List[str]) -> Dict[str, Any]:
+    def update_stop_words(self, body: list[str]) -> dict[str, Any]:
         """Update stop words of the index.
 
         Parameters
@@ -995,7 +997,7 @@ class Index():
             body
         )
 
-    def reset_stop_words(self) -> Dict[str, Any]:
+    def reset_stop_words(self) -> dict[str, Any]:
         """Reset stop words of the index to default values.
 
         Returns
@@ -1015,7 +1017,7 @@ class Index():
 
     # SYNONYMS SUB-ROUTES
 
-    def get_synonyms(self) -> Dict[str, List[str]]:
+    def get_synonyms(self) -> dict[str, list[str]]:
         """Get synonyms of the index.
 
         Returns
@@ -1032,7 +1034,7 @@ class Index():
             self.__settings_url_for(self.config.paths.synonyms)
         )
 
-    def update_synonyms(self, body: Dict[str, List[str]]) -> Dict[str, Any]:
+    def update_synonyms(self, body: dict[str, list[str]]) -> dict[str, Any]:
         """Update synonyms of the index.
 
         Parameters
@@ -1056,7 +1058,7 @@ class Index():
             body
         )
 
-    def reset_synonyms(self) -> Dict[str, Any]:
+    def reset_synonyms(self) -> dict[str, Any]:
         """Reset synonyms of the index to default values.
 
         Returns
@@ -1076,7 +1078,7 @@ class Index():
 
     # FILTERABLE ATTRIBUTES SUB-ROUTES
 
-    def get_filterable_attributes(self) -> List[str]:
+    def get_filterable_attributes(self) -> list[str]:
         """Get filterable attributes of the index.
 
         Returns
@@ -1093,7 +1095,7 @@ class Index():
             self.__settings_url_for(self.config.paths.filterable_attributes)
         )
 
-    def update_filterable_attributes(self, body: List[str]) -> Dict[str, Any]:
+    def update_filterable_attributes(self, body: list[str]) -> dict[str, Any]:
         """Update filterable attributes of the index.
 
         Parameters
@@ -1117,7 +1119,7 @@ class Index():
             body
         )
 
-    def reset_filterable_attributes(self) -> Dict[str, Any]:
+    def reset_filterable_attributes(self) -> dict[str, Any]:
         """Reset filterable attributes of the index to default values.
 
         Returns
@@ -1138,7 +1140,7 @@ class Index():
 
     # SORTABLE ATTRIBUTES SUB-ROUTES
 
-    def get_sortable_attributes(self) -> List[str]:
+    def get_sortable_attributes(self) -> list[str]:
         """Get sortable attributes of the index.
 
         Returns
@@ -1155,7 +1157,7 @@ class Index():
             self.__settings_url_for(self.config.paths.sortable_attributes)
         )
 
-    def update_sortable_attributes(self, body: List[str]) -> Dict[str, Any]:
+    def update_sortable_attributes(self, body: list[str]) -> dict[str, Any]:
         """Update sortable attributes of the index.
 
         Parameters
@@ -1179,7 +1181,7 @@ class Index():
             body
         )
 
-    def reset_sortable_attributes(self) -> Dict[str, Any]:
+    def reset_sortable_attributes(self) -> dict[str, Any]:
         """Reset sortable attributes of the index to default values.
 
         Returns
@@ -1199,7 +1201,7 @@ class Index():
 
     # TYPO TOLERANCE SUB-ROUTES
 
-    def get_typo_tolerance(self) -> Dict[str, Any]:
+    def get_typo_tolerance(self) -> dict[str, Any]:
         """Get typo tolerance of the index.
 
         Returns
@@ -1216,7 +1218,7 @@ class Index():
             self.__settings_url_for(self.config.paths.typo_tolerance)
         )
 
-    def update_typo_tolerance(self, body: Dict[str, Any]) -> Dict[str, Any]:
+    def update_typo_tolerance(self, body: dict[str, Any]) -> dict[str, Any]:
         """Update typo tolerance of the index.
 
         Parameters
@@ -1240,7 +1242,7 @@ class Index():
             body
         )
 
-    def reset_typo_tolerance(self) -> Dict[str, Any]:
+    def reset_typo_tolerance(self) -> dict[str, Any]:
         """Reset typo tolerance of the index to default values.
 
         Returns
@@ -1258,7 +1260,7 @@ class Index():
             self.__settings_url_for(self.config.paths.typo_tolerance),
         )
 
-    def get_pagination_settings(self) -> Dict[str, Any]:
+    def get_pagination_settings(self) -> dict[str, Any]:
         """Get pagination settngs of the index.
 
         Returns
@@ -1273,7 +1275,7 @@ class Index():
         """
         return self.http.get(self.__settings_url_for(self.config.paths.pagination))
 
-    def update_pagination_settings(self, body: Dict[str, Any]) -> Dict[str, Any]:
+    def update_pagination_settings(self, body: dict[str, Any]) -> dict[str, Any]:
         """Update the pagination settings of the index.
 
         Parameters
@@ -1299,7 +1301,7 @@ class Index():
         )
 
 
-    def reset_pagination_settings(self) -> Dict[str, Any]:
+    def reset_pagination_settings(self) -> dict[str, Any]:
         """Reset pagination settings of the index to default values.
 
         Returns
@@ -1315,7 +1317,7 @@ class Index():
         """
         return self.http.delete(self.__settings_url_for(self.config.paths.pagination))
 
-    def get_faceting_settings(self) -> Dict[str, Any]:
+    def get_faceting_settings(self) -> dict[str, Any]:
         """Get the faceting settings of an index.
 
         Returns
@@ -1331,7 +1333,7 @@ class Index():
 
         return self.http.get(self.__settings_url_for(self.config.paths.faceting))
 
-    def update_faceting_settings(self, body: Dict[str, Any]) -> Dict[str, Any]:
+    def update_faceting_settings(self, body: dict[str, Any]) -> dict[str, Any]:
         """Update the faceting settings of the index.
 
         Parameters
@@ -1357,7 +1359,7 @@ class Index():
         )
 
 
-    def reset_faceting_settings(self) -> Dict[str, Any]:
+    def reset_faceting_settings(self) -> dict[str, Any]:
         """Reset faceting settings of the index to default values.
 
         Returns
@@ -1376,14 +1378,14 @@ class Index():
 
     @staticmethod
     def _batch(
-        documents: List[Dict[str, Any]], batch_size: int
-    ) -> Generator[List[Dict[str, Any]], None, None]:
+        documents: list[dict[str, Any]], batch_size: int
+    ) -> Generator[list[dict[str, Any]], None, None]:
         total_len = len(documents)
         for i in range(0, total_len, batch_size):
             yield documents[i : i + batch_size]
 
     @staticmethod
-    def _iso_to_date_time(iso_date: Optional[Union[datetime, str]]) -> Optional[datetime]:
+    def _iso_to_date_time(iso_date: datetime | str | None) -> datetime | None:
         """
         Meilisearch returns the date time information in iso format. Python's implementation of
         datetime can only handle up to 6 digits in microseconds, however Meilisearch sometimes
@@ -1411,7 +1413,7 @@ class Index():
 
     def _build_url(
         self,
-        primary_key: Optional[str] = None,
+        primary_key: str | None = None,
     ) -> str:
         if primary_key is None:
             return f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
